pub fn render(diagnostic: &Diagnostic, request: Option<&Request>) -> ResponseExpand description
Render a diagnostic, using the request (when available) for the detail panels and to decide between HTML and JSON.
pub fn render(diagnostic: &Diagnostic, request: Option<&Request>) -> ResponseRender a diagnostic, using the request (when available) for the detail panels and to decide between HTML and JSON.