Serving static files out of a directory, for public/.
Structs
- Files
- Serves files from a directory, refusing anything that escapes it.
Functions
- content_
type - Guess a content type from the file extension.
Serving static files out of a directory, for public/.