Module files

Module files 

Serving static files out of a directory, for public/.

Structs

Files
Serves files from a directory, refusing anything that escapes it.

Functions

content_type
Guess a content type from the file extension.