pub struct TestResponse {
pub response: Response,
}Expand description
A response with assertions attached, each returning self so they chain.
Fields
response: ResponseImplementations
Sourceimpl TestResponse
impl TestResponse
pub fn status(&self) -> u16
pub fn body(&self) -> String
Sourcepub fn body_bytes(&self) -> &[u8] ⓘ
pub fn body_bytes(&self) -> &[u8] ⓘ
The raw body, for a response that is not text — a compressed one, say.
pub fn json(&self) -> Json
pub fn header(&self, name: &str) -> Option<&str>
pub fn assert_status(self, expected: u16) -> Self
pub fn assert_ok(self) -> Self
pub fn assert_not_found(self) -> Self
Sourcepub fn assert_see(self, needle: &str) -> Self
pub fn assert_see(self, needle: &str) -> Self
Assert the body contains this text.
pub fn assert_dont_see(self, needle: &str) -> Self
pub fn assert_header(self, name: &str, expected: &str) -> Self
pub fn assert_redirect(self, location: &str) -> Self
Sourcepub fn assert_json(self, path: &str, expected: impl Into<Json>) -> Self
pub fn assert_json(self, path: &str, expected: impl Into<Json>) -> Self
Assert a dotted path in the JSON body equals a value.
pub fn assert_json_missing(self, path: &str) -> Self